@@ -49,6 +49,8 @@
     (bus_ibus_impl_get_default ())
 #define BUS_DEFAULT_HOTKEY_PROFILE \
     (bus_ibus_impl_get_hotkey_profile (BUS_DEFAULT_IBUS))
+#define BUS_DEFAULT_KEYMAP \
+    (bus_ibus_impl_get_keymap (BUS_DEFAULT_IBUS))
 #define BUS_DEFAULT_REGISTRY \
     (bus_ibus_impl_get_registry (BUS_DEFAULT_IBUS))
 
@@ -69,12 +71,15 @@ struct _BusIBusImpl {
     GList *register_engine_list;
     GList *component_list;
 
+    gboolean use_sys_layout;
+
     BusRegistry     *registry;
 
     BusInputContext *focused_context;
     BusPanelProxy   *panel;
     IBusConfig      *config;
     IBusHotkeyProfile *hotkey_profile;
+    IBusKeymap      *keymap;
 
 };
 
@@ -95,6 +100,7 @@ BusFactoryProxy *bus_ibus_impl_lookup_factory       (BusIBusImpl        *ibus,
                                                      const gchar        *path);
 IBusHotkeyProfile
                 *bus_ibus_impl_get_hotkey_profile   (BusIBusImpl        *ibus);
+IBusKeymap      *bus_ibus_impl_get_keymap           (BusIBusImpl        *ibus);
 BusRegistry     *bus_ibus_impl_get_registry         (BusIBusImpl        *ibus);
 
 G_END_DECLS
