@@ -86,6 +86,7 @@ struct _IBusEngineClass {
     gboolean    (* process_key_event)
                                     (IBusEngine     *engine,
                                      guint           keyval,
+                                     guint           keycode,
                                      guint           state);
     void        (* focus_in)        (IBusEngine     *engine);
     void        (* focus_out)       (IBusEngine     *engine);
@@ -121,8 +122,6 @@ struct _IBusEngineClass {
                                      guint           button,
                                      guint           state);
 
-
-
     /*< private >*/
     /* padding */
     gpointer pdummy[8];
@@ -269,6 +268,7 @@ void         ibus_engine_hide_lookup_table
  * ibus_engine_forward_key_event:
  * @engine: An IBusEngine.
  * @keyval: KeySym.
+ * @keycode: keyboard scancode.
  * @state: Key modifier flags.
  *
  * Forward the key event.
@@ -276,6 +276,7 @@ void         ibus_engine_hide_lookup_table
 void         ibus_engine_forward_key_event
                                         (IBusEngine         *engine,
                                          guint               keyval,
+                                         guint               keycode,
                                          guint               state);
 
 /**
