@@ -37,7 +37,7 @@ from gettext import dgettext
 _  = lambda a : dgettext("ibus", a)
 N_ = lambda a : a
 
-ICON_OFF = "ibus-off"
+ICON_KEYBOARD = "ibus-keyboard"
 ICON_ENGINE = "ibus-engine"
 
 def show_uri(screen, link):
@@ -106,13 +106,14 @@ class Panel(ibus.PanelBase):
         self.__status_icon = gtk.StatusIcon()
         self.__status_icon.connect("popup-menu", self.__status_icon_popup_menu_cb)
         self.__status_icon.connect("activate", self.__status_icon_activate_cb)
-        self.__status_icon.set_from_icon_name(ICON_OFF)
+        self.__status_icon.set_from_icon_name(ICON_KEYBOARD)
         self.__status_icon.set_tooltip(_("IBus input method framework"))
         self.__status_icon.set_visible(True)
 
         self.__config_load_lookup_table_orientation()
         self.__config_load_show()
         self.__config_load_custom_font()
+        self.__config_load_show_icon_on_systray()
         self.__config_load_show_im_name()
         # self.__bus.request_name(ibus.panel.IBUS_SERVICE_PANEL, 0)
 
@@ -198,7 +199,7 @@ class Panel(ibus.PanelBase):
         self.__language_bar.set_enabled(enabled)
 
         if not enabled:
-            self.__set_im_icon(ICON_OFF)
+            self.__set_im_icon(ICON_KEYBOARD)
             self.__set_im_name(None)
         else:
             engine = self.__focus_ic.get_engine()
@@ -206,7 +207,7 @@ class Panel(ibus.PanelBase):
                 self.__set_im_icon(engine.icon)
                 self.__set_im_name(engine.longname)
             else:
-                self.__set_im_icon(ICON_OFF)
+                self.__set_im_icon(ICON_KEYBOARD)
                 self.__set_im_name(None)
         self.__language_bar.focus_in()
 
@@ -215,7 +216,7 @@ class Panel(ibus.PanelBase):
         self.__focus_ic = None
         self.__language_bar.set_enabled(False)
         self.__language_bar.focus_out()
-        self.__set_im_icon(ICON_OFF)
+        self.__set_im_icon(ICON_KEYBOARD)
         self.__set_im_name(None)
 
     def state_changed(self):
@@ -227,7 +228,7 @@ class Panel(ibus.PanelBase):
 
         if enabled == False:
             self.reset()
-            self.__set_im_icon(ICON_OFF)
+            self.__set_im_icon(ICON_KEYBOARD)
             self.__set_im_name(None)
         else:
             engine = self.__focus_ic.get_engine()
@@ -235,7 +236,7 @@ class Panel(ibus.PanelBase):
                 self.__set_im_icon(engine.icon)
                 self.__set_im_name(engine.longname)
             else:
-                self.__set_im_icon(ICON_OFF)
+                self.__set_im_icon(ICON_KEYBOARD)
                 self.__set_im_name(None)
 
 
@@ -279,6 +280,10 @@ class Panel(ibus.PanelBase):
         settings = gtk.settings_get_default()
         gtk.rc_reset_styles(settings)
 
+    def __config_load_show_icon_on_systray(self):
+        value = self.__config.get_value("panel", "show_icon_on_systray", True)
+        self.__status_icon.set_visible(True if value else False)
+
     def __config_load_show_im_name(self):
         value = self.__config.get_value("panel", "show_im_name", False)
         self.__language_bar.set_show_im_name(value)
@@ -292,6 +297,8 @@ class Panel(ibus.PanelBase):
             self.__config_load_show()
         elif name == "use_custom_font" or name == "custom_font":
             self.__config_load_custom_font()
+        elif name == "show_icon_on_systray":
+            self.__config_load_show_icon_on_systray()
         elif name == "show_im_name":
             self.__config_load_show_im_name()
         else:
